@@ -1,6 +1,6 @@
 /* Kernel crypto API AF_ALG Symmetric Cipher API
  *
- * Copyright (C) 2016 - 2019, Stephan Mueller <smueller@chronox.de>
+ * Copyright (C) 2016 - 2020, Stephan Mueller <smueller@chronox.de>
  *
  * License: see COPYING file in root directory
  *
@@ -184,6 +184,16 @@ int32_t kcapi_cipher_stream_update(struct kcapi_handle *handle,
 		return _kcapi_common_send_data(handle, iov, iovlen, MSG_MORE);
 }
 
+DSO_PUBLIC
+int32_t kcapi_cipher_stream_update_last(struct kcapi_handle *handle,
+					struct iovec *iov, uint32_t iovlen)
+{
+	if (handle->processed_sg <= handle->flags.alg_max_pages)
+		return _kcapi_common_vmsplice_iov(handle, iov, iovlen, 0);
+	else
+		return _kcapi_common_send_data(handle, iov, iovlen, 0);
+}
+
 DSO_PUBLIC
 int32_t kcapi_cipher_stream_op(struct kcapi_handle *handle,
 			       struct iovec *iov, uint32_t iovlen)
